..
      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

.. kuryr documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=================================
Welcome to kuryr's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   contributing
   cli/index
   releasenotes

Design and Developer Docs
==========================

.. toctree::
   :maxdepth: 1

   devref/index

Kuryr Specs
===========

.. toctree::
   :maxdepth: 2

   specs/index

Indices and tables
==================

* :ref:`search`

